about summary refs log tree commit diff
diff options
context:
space:
mode:
authorTim Steinbach <tim@nequissimus.com>2018-12-10 10:10:19 -0500
committerTim Steinbach <tim@nequissimus.com>2018-12-10 10:11:33 -0500
commit97ad321e4268caf803f81492c6914daf3029d533 (patch)
treea386d758615b133f3373c56de253adba823cdc41
parentea22830eaf5e722fc9ac5c39e5f47c560fa0fca7 (diff)
downloadnixlib-97ad321e4268caf803f81492c6914daf3029d533.tar
nixlib-97ad321e4268caf803f81492c6914daf3029d533.tar.gz
nixlib-97ad321e4268caf803f81492c6914daf3029d533.tar.bz2
nixlib-97ad321e4268caf803f81492c6914daf3029d533.tar.lz
nixlib-97ad321e4268caf803f81492c6914daf3029d533.tar.xz
nixlib-97ad321e4268caf803f81492c6914daf3029d533.tar.zst
nixlib-97ad321e4268caf803f81492c6914daf3029d533.zip
zsh-autosuggestions: Fix module for 0.5.0
The update for zsh-autosuggestions in #51752 broke the module.
This fix reflects the required changes.
-rw-r--r--nixos/modules/programs/zsh/zsh-autosuggestions.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/nixos/modules/programs/zsh/zsh-autosuggestions.nix b/nixos/modules/programs/zsh/zsh-autosuggestions.nix
index 416f4c9c6751..ded17f38a618 100644
--- a/nixos/modules/programs/zsh/zsh-autosuggestions.nix
+++ b/nixos/modules/programs/zsh/zsh-autosuggestions.nix
@@ -18,13 +18,13 @@ in
     };
 
     strategy = mkOption {
-      type = types.enum [ "default" "match_prev_cmd" ];
-      default = "default";
+      type = types.enum [ "history" "match_prev_cmd" ];
+      default = "history";
       description = ''
         Set ZSH_AUTOSUGGEST_STRATEGY to choose the strategy for generating suggestions.
         There are currently two to choose from:
 
           * default: Chooses the most recent match.
           * match_prev_cmd: Chooses the most recent match whose preceding history item matches
             the most recently executed command (more info). Note that this strategy won't work as
             expected with ZSH options that don't preserve the history order such as
@@ -51,7 +51,7 @@ in
       source ${pkgs.zsh-autosuggestions}/share/zsh-autosuggestions/zsh-autosuggestions.zsh
 
       export ZSH_AUTOSUGGEST_HIGHLIGHT_STYLE="${cfg.highlightStyle}"
-      export ZSH_AUTOSUGGEST_STRATEGY="${cfg.strategy}"
+      export ZSH_AUTOSUGGEST_STRATEGY=("${cfg.strategy}")
 
       ${concatStringsSep "\n" (mapAttrsToList (key: value: ''export ${key}="${value}"'') cfg.extraConfig)}
     '';
@@ -18,13 +18,13 @@ in
         There are currently two to choose from:
 
-          * default: Chooses the most recent match.
+          * history: Chooses the most recent match.
           * match_prev_cmd: Chooses the most recent match whose preceding history item matches
             the most recently executed command (more info). Note that this strategy won't work as